F相关系数为0表明两个变量之间不存在任何关系
F密度函数可以是负的。
T当总体G1和G2为正态总体且协方差相等时，选用马氏距离。
T标准化随机变量的协方差阵与原变量的相关系数相同。
F样本相关系数r∈(－1, 1)
F密度函数可以是负的。
T如果相关系数为0，则表明两个变量间不存在线性相关
T一个行列式中某一行（列）所有元素的公因子可以提到行列式符号的外边。
F numpy中产生全1的矩阵使用的方法是empty。
T相关关系是指变量间不确定性的依存关系。
F pandas中head(n)的意思是获取最后的n行数据。
T Numpy的ndarray(数组)中，使用shape()来表示数组的维度尺寸。
F Python语言是非开源的语言。
F脸谱图是用脸部特征表达变量间的相关性。
T通过对多变量的脸谱图分析，可以直观地对原始数据资料进行归类或比较研究。
F设要分析的资料共有p个变量，当p值较大时一张雷达图也可以清晰表达各观测之间的接近程度。
T雷达图是目前应用较为广泛的多元资料进行作图的方法，利用雷达图可以很方便地研究个样本点之间的关系并对样品进行归类。
F星图和星座图很相似，甚至有的文献把两者看成是一回事。
T利用星座图可以方便地对样本点进行分类，再星座图上比较靠近的样本点比较相似，可分为一类。
F多变量的图表示法使资料的呈现方式更直观、更形象，可以作为定量分析的研究结果并形成结论。
F只要变量的指标数目不变，对应脸谱图的特征就不变。
T马氏距离在协差阵为单位阵时退化为欧氏距离
F马氏距离受单位的影响。
T相关系数度量了两个随机变量之间依赖关系的强弱。
T Cov(X, Y) = 0, 称X与Y是不相关的。
T随机向量X的协方差阵是对称矩阵。
F若p维随机向量X的协方差阵存在, 且每个分量的方差大于零，则X的相关阵的元素计算公式为: r_ij = (cov(X_i, X_j))/(D(X_i)D(X_j)), i, j = 1, 2, …, p。
T设两个随机向量X和Y是相互独立的，F(x, y)为(X, Y)的联合分布函数，G(x)和H(y)分别为X和Y的分布函数，则F(x, y) = G(x)H(y)。
F设两个随机向量X和Y是相互独立的，f(x, y)为(X, Y)的密度函数，g(x)和h(y)分别为X和Y的密度函数，则f(x, y) = g(x)+h(y)。
T正态分布的条件分布仍为条件分布。
F相关关系数不会取负值。
T相关系数的绝对值不会大于1。
F若A是退化矩阵，则A-1一定存在
T若A为p阶对称矩阵，则存在正交矩阵T和对角矩阵Λ = diag(λ_1, λ_2, ⋯λ_p)，使得A = TΛT'。
T若向量x和y的内积为0，则说明向量x和y垂直。
F若A是一个正交矩阵，则A的行列式为1。
T若A和B均为p阶方阵，则 | AB |= |A | |B|。
判断题二…………………………………………………………..
T单纯依靠相关与回归分析，无法判断事物之间存在的因果关系
F距离判别法考虑到了误判之后所造成的损失的差异。
T判别分析最基本要求是分组类型在两组以上且解释变量必须是可测量的。
T在回归分析中，变量间的关系若是非确定关系，那么因变量不能由自变量唯一确定。
F聚类分析仅能进行样本聚类。
F聚类分析属于有指导的学习分类方法。
T进行样品聚类分析时，“靠近”往往由某种距离来刻画。
F类平均法进行系统聚类的的思想是来于方差分析，如果类分得正确，同类样品的离差平方和应当较小，类与类之间的离差平方和应当较大。
T聚类分析时可通过碎石图确定最终的分类数。
F针对同一多元数据，不同的方法聚类的结果相同。
T系统聚类法中，对于那些先前已被“错误”分类的样品不再提供重新分类的机会。
T K-均值法只能用于对样品的聚类，而不能用于对变量的聚类。
T有序样品的聚类的实质上是需要找出一些分点，将数据划分成几个分段，每个分段看作一类，称这种分类也可称为分割。
T k均值法的类个数需事先指定
T进行多元数据的指标聚类时，可根据相关系数或某种关联性度量来聚类。
F最长距离法中，选择最小的距离作为新类与其他类之间的距离，然后将类间距离最小的两类进行合并，一直合并到只有一类为止。
F K均值聚类分析中，样品一旦划入某一类就不可改变。
F名义尺度的指标用一些类来表示，这些类之间有等级关系，但没有数量关系。
T下图为应用SPSS软件制作的散点图矩阵，图中城镇人口比重与平均预期寿命存在强线性相关性。
T如果相关系数为0，则表明两个变量间不存在线性相关。
T聚类分析的目的就是把相似的研究对象归类。
T判别分析中, 若两个总体的协差阵相等, 则 Fisher判别与距离判别等价。
T一般而言，不同聚类方法的结果不完全相同
F在系统聚类过程中，聚合系数越大，合并的两类差异越小。
选择三…………………………………
T主成分分析时，对数据进行标准化的过程可能抹杀原始变量离散程度差异。
F主成分分析要求数据来自于正态总体。
T对来自多元正态总体的数据，主成分分析的主成分就是按数据离散程度最大的方向进行坐标轴旋转。
T在主成分分析的过程中，得到的各个主成分的方差依次递减。
F对于两组的判别，最大后验概率法的判别规则可使两个误判概率之和达到最小。
T对于两组皆为正态组及协差阵相同的情形下，两组先验概率相同及两个误判代价也相等时的贝叶斯判别等价于距离判别，也等价于费希尔判别。
T主成分分析实质上是线性变换，无假设检验。
F一般地说，从同一原始变量的协方差矩阵出发求得的主成分与从原始变量的相关矩阵出发求得的主成分相同。
T选取主成分还可根据特征值的变化来确定。求解主成分的过程实际就是对矩阵结构进行分析的过程。
F对于度量单位不同的指标或是取值范围彼此差异非常大的指标，可直接从协方差矩阵出发进行主成分分析。
F主成分分析只是要达到目的的一个中间结果（或步骤），没有实际意义。
T选取主成分还可根据特征值的变化来确定。求解主成分的过程实际就是对矩阵结构进行分析的过程。
F对于度量单位不同的指标或是取值范围彼此差异非常大的指标，可直接从协方差矩阵出发进行主成分分析。
T为了使得因子分析的结果更易于解释，进行正交因子旋转，旋转后，新的公共因子仍然彼此独立。
F因子得分是为了考察每一个样品性质之间的关系。
T因子分析中，载荷矩阵中的每一个元素代表的是变量Xi与公共因子Fj之间的关系。
F因子分析中，利用主成分法求解的载荷系数与主成分分析中的主成分线性方程的系数一样。
T因子分析中，公因子Fj的方差贡献表示的是公共因子Fj对于原始数据X中的每一分量Xi（i = 1，2，…，p）所提供的方差的总和。
F利用主成分法得到的因子载荷是唯一的。
T主成分的数目大大少于原始变量的数目。
F Logistic回归对于自变量有要求，度量变量或者非度量变量都不可以进行回归。
F因子分析把变量分成公共因子和独立因子两部分因素。
F因子载荷经正交旋转后, 各变量的共性方差和各因子的贡献都发生了变化。
F因子分析只能用于研究变量之间的相关关系。
F主成分分析是将原来较少的指标扩充为多个新的的综合指标的多元统计方法。
F Logistic回归对于自变量有要求, 度量变量或者非度量变量都不可以进行回归。
T因子载荷量是指因子结构中原始变量在因子分析时抽取出的公共因子的相关程度。

选择一………………………………..
关于 Python 语言的特点，以下选项中描述错误的是 【A.Python 语言是非开源语言】

使用pandas时需要导入下面哪个？ 【A import pandas as pd】

Numpy中矩阵转换为向量用下面哪个函数？【b resize】

numpy中向量转成矩阵使用下面哪个函数？【a reshape】


下列变量中，属于负相关的是 【价格下降，消费增加】

如果正态随机向量X的各分量是相互独立的随机变量, 那么随机变量X的协方差阵是下面哪个？【对角阵】

多元正态分布是以下哪项的推广。【一元正态分布】

Numpy的ndarray(数组)中，使用下面哪个来表示数组的维度尺寸。【Shape】

有数组 n = np.arange(24).reshape(2, -1, 2, 2)，n.shape的返回结果是什么？【(2, 3, 2, 2)】

常用统计函数中，mean计算下面的哪个？【数组的均值】

多变量的图表示法不包括  【箱线图】

将所有样本点都点在一个半圆里面，根据样本点的位置可以直观地对样本点之间的相关性进行分析的多变量表示图是 【星座图】

利用其可以很方便的研究个样本点之间的关系并对样本进行分类的是 【雷达图和脸谱图】

在脸谱图中，脸谱的绘制顺序是脸庞高度、脸庞宽度、脸庞轮廓、嘴唇高度、嘴唇宽度、笑容曲线、眼睛高度、眼睛宽度、头发高度、头发宽度、头发造型、鼻子高度、鼻子宽度、耳朵宽度、耳朵高度共计15项，输入的数据变量依次为X1~X10共计10个变量，则X1表示的脸部特征是 【脸庞高度和头发造型】


将圆平等分并由圆心连接各分点，将所得的p条线段作为坐标轴，根据各变量的取值对各坐标轴做适当刻度，对任意样本点可分别在p轴上确定其坐标，在各坐标轴上点出其坐标并依次连接p个点。这样做出的图是 【雷达图】

设X~N(μ, Σ)，则X离μ越近（远）密度越大（小），度量这里远近的距离应是 【马氏距离】

设随机变量X和Y都服从正态分布, 且它们不相关, 则 【X与Y未必独立】

用样本的信息推断总体，样本应该是 【总体中随机抽取的一部分】

抽样调查的目的是  【样本推断总体特征】

设A, B, C均为常数矩阵，随机向量X和Y的均值特征不包括 【E(AX) = AE(X)A'】

设A, B, C均为常数矩阵，随机向量X和Y的协差阵D[X]和D[Y]性质包括  【D(AX) = AD(X)A'】

就大部分统计问题而言，欧氏距离存在缺点不包括 【与变量的分布特征有关】

T分布的均值是 【0】

假设检验的一般步骤中不包括 【对总体参数的置信区间作出估计】

假设检验是基于何种情况提出来的？【H0成立】

比较两组均值向量，检验一般采用哪种方法  【t检验】

进行多元均值检验时，假设H0: μ = μ_0, H1: μ≠μ_0, 协方差阵Σ已知且α显著性水平下的分位点为c，拒绝域为：  【统计量＞c】

进行多元均值检验时，假设H0: μ = μ_0, H1: μ≠μ_0, 协方差阵Σ未知且α显著性水平下的分位点为c，拒绝域为  【统计量＞c】

在进行两总体的均值比较时，假设H0: μ_1 = μ_2, H1: μ_1≠μ_2, 协方差阵Σ相等时，且α显著性水平下的分位点为c，拒绝域为  【统计量＞c】

在进行两总体的均值比较时，假设H0: μ_1 = μ_2, H1: μ_1≠μ_2, 协方差阵Σ不相等时，且α显著性水平下的分位点为c，拒绝域为：【统计量＞c】

在进行两总体的均值比较时，假设H0: μ_1 = μ_2, H1: μ_1≠μ_2, 协方差阵Σ不相等时，且α显著性水平下的分位点为T_(p, n1+n2-2) ^ 2 (α)，拒绝域为： 【统计量T ^ 2 > T_(p, n1+n2-2) ^ 2 (α)】】

在假设检验中，如果p值大于显著性水平α，就认为总体均值与检验值之间？  【无显著差异】

设A是3阶方阵，且 | A |= -2，则 | A ^ (-1) |=（ ）。 【-1/2】

对于任意n阶方阵A, B，总有（ ）  【| AB |= |BA|】

设A = diag(a_11, a_22, ⋯, a_pp)且a_ii≠0(i=1, 2, ⋯p)，以下说法错误的是（ ）。  【矩阵A有小于p个特征向量】

设α1，α2，…，αm均为n维向量，那么，下面关于向量的说法正确的是（ ）。  【若α1，α2，…，αm线性相关，则对任意一组不全为零的数k1，k2，…，km，都有k1α1+k2α2 +…+kmαm = 0】

设a = (2, -4, 1)'，b=(3,5,-1)'，ab'的非零特征值为（ ）。 【 - 15】

三个总体样本G1, G2和G3的分布分别为：  【G3】

设有样本X（0, 3），Y（1, 2），求XY的欧式距离  【根号2】

选择二…………………………
下列变量中，属于负相关的是  【价格下降，消费增加】

在以下四个散点图中，适用于做线性回归的是？  【①③】

假如你在训练一个线性回归模型，有下面两句话：如果数据量较少，容易发生过拟合。如果假设空间较小，容易发生过拟合。关于这两句话，下列说法正确的是？  【1 正确，2 错误】

两个变量与x的回归模型中，通常用 来刻画回归的效果，则正确的叙述是 【 R2越小，残差平方和越大】

下列说法中正确的是  【人的知识与其年龄具有相关关系】

一位母亲记录了儿子3~9岁的身高，由此建立的身高与年龄的回归直线方程为y'= 7.19x+73.93，据此可以预测这个孩子10岁时的身高，则正确的叙述是  【升高在145.83cm左右】

在画两个变量的散点图时，下面哪个叙述是正确的  【自变量在x轴上，因变量在y轴上】

在对两个变量x，y进行线性回归分析时，有下列步骤：①对所求出的回归直线方程作出解释; ②收集数据
 ，i = 1, 2, ...., n；③求线性回归方程; ④求未知参数; ⑤根据所搜集的数据绘制散点图。如果根据可行性要求能够作出变量x，y具有线性相关结论，则在下列操作中正确的是  【②⑤④③①】

线性回归中普通最小二乘估计的缺点是  【回归直线被拉向方差大的项；】

在回归分析中，代表了数据点和它在回归直线上相应位置的差异的是  【残差平方和】

对两变量的散点图拟合最好的回归线，必须满足一个基本的条件是  【求和(y-y ^)2最小】

下面哪一项不是判别分析的方法？  【协方差阵判别】

决策树中不包含以下哪种结点？  【外部结点（external node）】

下面哪一个选项不是判别分析的方法：【协方差阵判别】

设有样本X（0, 3），Y（1, 2），求XY的欧式距离  【根号2】

使用“最大后验概率准则”得到的贝叶斯判别规则为   【A】

以下哪种判别方法既可用于判别分类也可用于分离各组。  【费希尔判别】

两组情形下的最小期望误判代价法的判别规则包含三个比值，其中最富有实际意义的是  【误判代价之比】

如果对某公司在一个城市中的各个营业点按彼此之间的路程远近来进行聚类，则最适合采用的距离是  【绝对值距离】

聚类分析的目的是  【降维】

对样本分类还不清楚的时候，适合首先进行哪种分析  【聚类分析】

适合对大样本数据进行聚类分析的方法是  【K-均值聚类】

根据聚类的对象不同，聚类可以分为     【有序聚类和K均值聚类】

聚类分析中，通常使用（    ）来衡量两个对象之间的相异度  【距离】

一项研究中对中国、香港等12 个国家或地区的多项经济指标进行了聚类分析，得到的树状图如下  【分为四类时，日本、中国、马来西亚构成一个类】

当不知道数据所带标签时，可以使用哪种技术促使带同类标签的数据与带其他标签的数据相分离？  【聚类】

设，则x离μ越远（近）密度越小（大）。度量这里远近的距离应是:  【马氏距离】

聚类分析方法中，下列哪种方法也称为快速聚类法  【Kmeans聚类】

不适合对变量聚类的方法有  【K均值法】

选择三………………………………………………
主成分分析中，  【有必要考虑变量的量纲，避免出现“大数吃小数”】

关于第一个主成分，下列描述正确的是   【其累积方差贡献率最大】

关于第一个主成分，下列描述正确的是  【其累积方差贡献率最大】

主成分分析中各主成分之间是  【互不相关】

在利用主成分分析进行综合评价时，要对样本观测进行一些变换，最常用的是  【同向化变换】

为了更充分有效地代表原始变量的信息，不同的主成分应携带不同的信息。以第一、第二主成分Y1\Y2为例，  【cov(Y1, Y2) = 0】

主成分分析的主要任务有  【确定主成分个数】

利用主成分分析得到的各个主成分之间为下面哪个选项？  【最小】

因子分析中对于因子载荷的求解最不常用的方法是。  【极小似然法】

第k个主成分yk的系数向量是下面哪个？  【第k个特征根所对应的特征向量】

利用主成分分析得到的各个主成分之间为下面哪个？  【互不相关】

因子分析把变量分成下列两部分因素。  【公共因子和特殊因子】

填空一………………………………
Numpy中创建全为0的矩阵使用  【zeros】

pandas中，【read_csv】 用来读取csv文件

多元分析研究的是 【多指标问题】的统计总体。

协方差和相关系数仅仅是变量间 【离散程度】的一种度量，并不能刻画变量间可能存在的 【关联程度关系】

设随机向量X = (x1，x2, x3, x4)'的相关阵R为 则x1和x3的相关系数为 【- 0.5】

设a = (2, -4, 1)'，b=(4,1,-4)'，则a和b的夹角为  【90】

若A为4阶非退化矩阵，若2为矩阵A的一个特征值为【1/2 | 0.5】，对应的特征向量为（1，0，3，4）
，则A逆矩阵的一个特征值为 【0.5】 ，对应特征向)量为【1, 0, 3, 4】

设矩阵的秩为2，则λ= 【1】

设X=(X_1, X_2, …, X_p)'有为p个分量，μ为X的均值向量，则μ是
 【p】 维向量。

几何平面上的点p=(x1, x2)到原点O=(0, 0)的欧氏距离是 【(x1 ^ 2+x2 ^ 2) ^ (1/2)】

如果正态随机向量X的协方差阵∑是对角阵，则X的各分量是  【相互独立】  的随机变量。

在实际问题中, 通常可以假定被研究的对象是  【多元正态分布】, 但分布中的参数μ和Σ是未知的, 一般的做法是通过样本来估计。

数理统计中常用的抽样分布卡方分布，在多元统计中, 与之对应的分布为 【Wishart分布】

多元统计研究的是多指标问题, 为了了解总体的特征, 通过对总体抽样得到代表总体的样本但因为信息是分散在每个样本上的,
就需要对样本进行加工, 把样本的信息浓缩到不包含未知量的样本函数中, 这个函数称为  【统计量】

S2=…是  【样本方差】 的计算公式

X平均是   【样本均值】的计算公式。

假设（X, Y）是二元随机变量，则Cov=(X, Y)是  【总体协方差】  的计算公式

设X、Y从均值向量为μ，协方差阵为∑的总体G中抽取的两个样品，定义X、Y两点之间的马氏距离为   【(X-Y)'Σ^(-1) (X-Y)|(X-Y)'∑^ (-1)(X-μ)】

多元数据的协方差阵检验中，需分析当前的波动幅度与过去的波动情形有无显著差异，此时要检验的假设H0为  【Σ=Σ_0】

多元数据协方差阵检验中，需要了解这多个总体之间的波动幅度有无明显的差异，此时要检验的假设的备择假设H1  【Σ_i不全相等】

多总体的均值向量检验中，假设r个总体的方差相等，要检验的假设H0是μ_1=μ_2=⋯=μ_r, 备择假设H1是   【至少存在两个均值不等】

【散点图矩阵】  是借助两变量散点图的作图方法，它可以看作是一个大的图形方阵，
其每一个非主对角元素的位置上是对应行的变量与对应列的变量的散点图。

进行单指标检验时，假设H0: H0: μ=μ_0, H1: μ≠μ_0, 计算得到统计量的数值为1.833，临界值t为0.45，此时应【拒绝】 原假设

针对连续变量的统计推断方法中，最常用的有T检验和【方差分析】

常用的Minkowski距离公式为…，当q=1时，它表示【曼哈顿距离】

常用的Minkowski距离公式为…，当q=2时，它表示【欧式距离】

常用的Minkowski距离公式为…，当q趋于正无穷时，它表示【切比雪夫距离】

如果X和Y在统计上独立，则相关系数等于【0】

相关系数r的取值范围是【- 1≤r≤1】

填空二……………………………………
判别分析是判别样品【所属类型】的一种统计方法，常用的判别方法有【距离判别】【Fisher判别】【Bayes判别】逐步判别法。

聚类分析就是分析如何对样品(或变量)进行量化分类的问题。通常聚类分析分为【Q型】 聚类和【R型】聚类。

学习回归分析的目的是对实际问题进【预测】和控制。

判别分析适用于被解释变量是【非度量】变量的情形。

与其他多元线性统计模型类似，判别分析的假设之一是每一个判别变量（解释变量）不能是其他判别变量的【线性】组合，
假设之二是各组变量的【协方差矩阵】等，假设之三是各判别变量遵从【多元正态】分布。

贝叶斯统计的思想是：假定对研究对象已有一定的认识，常用【先验概率】分布来描述这种认识，然后我们取得一个样本，
用样本来修正已有的认识，得到【后验概率】分布，各种统计推断就都可以通过这个分布来进行。

按经典假设，线性回归模型中的解释变量应是非随机变量，且与随机误差项【不相关】

回归分析中定义的解释变量和被解释变量都是【随机】变量

聚类和分类的区别是，【分类】分析是一种有监督学习方法，而【聚类】分析是一种无监督学习方法。

【聚类分析】是将分类对象分成若干类，相似的归为同一类，不相似的归为不同的类

进行系统聚类分析时，计算初始6个样本（X1…X6）的距离矩阵为：若类之间连接应用最大距离方法，
最先聚类的是【X5和X6 | X5，X6 | X5 X6 | X5, X6 | X5X6】

进行系统聚类分析时，计算初始6个样本（X1…X6）的距离矩阵为 若类之间连接应用最小距离方法，
最先聚类的是【X5和X6 | X5，X6 | X5 X6 | X5, X6 | X5X6】

进行系统聚类分析时，计算初始6个样本（X1…X6）的距离矩阵为：…若类之间连接应用最小距离方法，
假设将X5和X6聚为一类定义为X7，则X7与X1的距离d(7, 1)=【6】

Q型聚类法是按样品进行聚类，R型聚类法是按变量进行聚类, 9. Q型聚类相似度统计量是【距离】，而R型聚类统计量通常采用【相似系数】

常用的Minkowski距离公式为…，当q=1时，它表示【曼哈顿距离】

回归分析中从研究对象上可分为一元和【多元】

聚类分析中【模糊聚类】方法的基本思想是通过优化目标函数得到每个样本点对所有类中心的隶属度，从而对样本进行自动分类。

回归分析中，被预测或被解释的变量称为【因变量】

填空三………………………………..
因子分析中，将每个原始变量分解为两个部分，一个部分由所有变量共同具有的少数几个【公共因子】组成的，
另一个部分是每个变量独自具有的因素，即【特殊因子】

设X=(x_1, x_2, x_3)为标准化后的随机变量，将其协方差矩阵通过因子分析分解为…x_1的共同度【0.872】
，x_1的剩余方差【0.128】公因子F_1与x_1的协方差=
【0.934】。（结果保留小数点后三位）

对多元数据X（x1, x2, x3, x4, x5）进行了主成分分析, 样本的特征值λ_1=2.857，λ_2=0.809，λ_3=0.609，λ_4=0.521，λ_5=0.203
对应特征向量p1=(0.464, 0.457, 0.470, 0.421, 0.421), p1=(0.240, 0.509, 0.260, -0.526, -0.582),
则第一主成分Y1的计算公式是【Y1=0.464x1+0.457x2+0.470x3+0.421x4+0.421x5】

进行K-均值聚类时，碎石图如图所示，则最优的分类数为【3】

【主成分分析】是利用降维的思想，在损失很少信息的前提下把多个指标转化为几个综合指标的多元统计方法。

主成分分析通常把转化生成的综合指标称之为主成分，其中每个主成分都是原始变量的【线性组合】且各个主成分之间互不相关，
这就使得主成分比原始变量具有某些更优越的性能。

主成分分析中我们所说的保留原始变量尽可能多的信息，也就是指的生成的较少的综合变量的方差和尽可能接近于原始变量【方差】的总和。

主成分分析中可以利用【协方差矩阵】求解主成分。

对多元数据X（x1, x2, x3, x4）进行了主成分分析, 样本的特征值λ_1=2.857，λ_2=0.809，λ_3=0.702，λ_4=0.025
，则第一主成分的方差贡献率是【65】% (保留百分数的整数位)。

在进行主成分分析得出协方差阵或是相关阵发现最小特征根接近于零时，意味着中心化以后的原始变量之间存在【多重共线性】，
即原始变量存在着不可忽视的重叠信息

主成分的协方差矩阵为【对角矩阵】

因子分析中因子载荷系数aij的统计意义是第i个变量与第j个公因子的【相关系数】

多元分析中常用的统计量有【样本均值向量】【样本协差阵】【样本离差阵】【样本相关系数矩阵】每题可以有多个空。
【答案一 | 答案二 | 答案三】题目创建后不可修改填空数量。

主成分分析是利用【降维】 的思想，在损失很少的信息前提下，把多个指标转化为几个综合指标的多元统计方法。



编程………………………………………
写出贡献率最大的主成分线性方程
现在要用主成分做降维处理，且原始数据在降维前需采用均值标准化后才参与计算，最后给出特征值最大的第一主成分的变换公式。
【
import numpy as np
a=input()
b=input()
b1=np.array([int(i) for i in b.split(',')])
num=np.array([float(i) for i in a.split(',')]).reshape(b1[0], b1[1])
# 均值标准化
x=(num-np.mean(num))/np.std(num)
x1=np.cov(x.T)
# 特征值、特征向量
u, v=np.linalg.eig(x1)
# 比较特征值，得出最大的特征值
if u[0] > u[1]:
    index=0
else:
    index=1
print('第1主成分={:.5f}*(x1-{:.2f}){:+.5f}*(x2-{:.2f})'.format(
    v[0][index], np.mean(num, axis=0)[0], v[1][index], np.mean(num, axis=0)[1]))
】


通过分析匹萨直径与价格的线性关系，可预测任意直径匹萨的价格。假设我们查到了部分匹萨的直径与价格的数据，如下表所示请预测直径为12英寸的披萨的价格。
【
import numpy as np
from sklearn.linear_model import LinearRegression
a=input()
b=input()
c=input()
X1=list(map(int, a.split(' ')))
y1=list(map(float, b.split(' ')))
n=int(c)
X=np.mat(X1).reshape(5, 1)
y=np.mat(y1).reshape(5, 1)
model=LinearRegression()
model.fit(X, y)
print("Predict 12 inch cost:$%.2f" % model.predict([[n]]), end = "")
】


已知有两类数据和二者的先验概率，已知P(w1)=0.6，P(w2)=0.4。w1中数据点的坐标对应如下： W2中数据点的坐标对应如下
【
from numpy import *
import numpy as np
import math
x1=array([float(i) for i in input().split(',')])
y1=array([float(i) for i in input().split(',')])
w1=mat(vstack((x1, y1)))
x2=array([float(i) for i in input().split(',')])
y2=array([float(i) for i in input().split(',')])
w2=mat(vstack((x2, y2)))
mean1=np.mean(w1, 1)
mean2=np.mean(w2, 1)
dimens1, nums1=w1.shape[:2]
samples_mean1=w1 - mean1
s_in1=0
for i in range(nums1):
 x=samples_mean1[:, i]
 s_in1 += dot(x, x.T)
dimens2, nums2=w2.shape[:2]
samples_mean2=w2 - mean2
s_in2=0
for i in range(nums2):
 x=samples_mean2[:, i]
 s_in2 += dot(x, x.T)
s=s_in1 + s_in2
s_t=s.I
w=dot(s_t, mean1 - mean2)
w_new=w.T
m1_new=dot(w_new, mean1)
m2_new=dot(w_new, mean2)
pw1=0.6
pw2=0.4
w0=m1_new*pw1+m2_new*pw2
0.23, 1.52, 0.65, 0.77, 1.05, 1.19, 0.29, 0.25, 0.66, 0.56, 0.90, 0.13, - \
    0.54, 0.94, -0.21, 0.05, -0.08, 0.73, 0.33, 1.06, -0.02, 0.11, 0.
2.34, 2.19, 1.67, 1.63, 1.78, 2.01, 2.06, 2.12, 2.47, 1.51, 1.96, 1.83, 1.87, 2.29, 1.77, 2.39, 1.56, 1.93, 2.20, 2.45, 1.75, 1.69, 2.48, 1
1.40, 1.23, 2.08, 1.16, 1.37, 1.18, 1.76, 1.97, 2.41, 2.58, 2.84, 1.95, 1.25, 1.28, 1.26, 2.01, 2.18, 1.79, 1.33, 1.15, 1.70, 1.59, 2.93, 1
1.02, 0.96, 0.91, 1.49, 0.82, 0.93, 1.14, 1.06, 0.81, 1.28, 1.46, 1.43, 0.71, 1.29, 1.37, 0.93, 1.22, 1.18, 0.87, 0.55, 0.51, 0.99, 0.91, 0
1, 1.5
x=mat(array([float(i) for i in input().split(',')]).reshape(2, 1))
y_i=w_new * x[:, 0]
if y_i > w0:
 print('该点属于第一类')
else:
 print('该点属于第二类')
】




已知一批数据，有两个变量：销售额和利润，有8个样本：采用K均值聚类算法对样本进行聚类，判断公司A所在类，并输出该类的中心坐标。
【
import numpy as np
from sklearn.cluster import KMeans
a=input()
b=input()
c=input()
t1=np.array([float(i) for i in a.split(' ')])
t2, t3=np.array([int(i) for i in b.split(' ')])
t4=int(c)
n=np.array(t1).reshape(t2, t3)
kmeans=KMeans(n_clusters = t4)
kmeans.fit(n)
m=kmeans.labels_[0]
print("A公司所在类的中心为：{:.2f},{:.2f}。".format(kmeans.cluster_centers_[m, 0], kmeans.cluster_centers_[m,
1]))
】



比较10种咖啡豆的质量，由5名专业人员对每种咖啡的香气、甜感、酸质、醇厚度、风味、余韵和平衡7项指标进行打分，最低分1分，最高分为10分，得到每种咖啡的每项指标的平均得分。

【
import numpy as np
from sklearn.cluster import AgglomerativeClustering
temp=np.array([float(i) for i in input().split(' ')])
n_samplesj, n_features=np.array([int(i) for i in input().split(' ')])
X=np.array(temp).reshape(n_samplesj, n_features)
n_clusters=int(input())
hc=AgglomerativeClustering(n_clusters = n_clusters,
                           affinity = 'correlation', linkage = 'complete')
hc.fit(X.T)
hcl=hc.labels_
if hcl[0] == hcl[2]:
 print("香气和酸质属于一类。")
else:
 print("香气和酸质不属于一类。")
】



输入25个整型数据，然后将其转换为5X5的矩阵，求其特征值及特征向量，正确的输入格式请见样例，若输入的格式不是int型或者输入个数不对，输出：输入有错！

【

import numpy as np
a=input().split(" ")
if len(a) != 25:
    print("输入有错！")
else:
    try:
        a=[int(i) for i in a]
        a=[a[i:i + 5] for i in range(0, len(a), 5)]
    except:
        print("输入有错！")
    eig_vals, eig_vectors=np.linalg.eig(a)
    print(eig_vals, '\n', eig_vectors)
】


有两组数据，分别是31个地区城镇居民年人均可支配收入和年人均消费性支出数据，人均可支配收入为

【
import numpy as np
s1=input()
s2=input()
n=[]
num=[float(n) for n in s1.split()]
for i in range(0, len(num), 31):
    x=num[i:i+31]
    n.append(x)
n=np.matrix(n)
nn=np.corrcoef(n)
print(nn)

】



from setuptools import setup
from setuptools import find_packages


VERSION = '0.0.8'

setup(
    name='duoyuantongji',  # package name
    version=VERSION,  # package version
    description='my package test',  # package description
    packages=find_packages('src'),
    package_data={"evatool.resource": [
        "*.json", "*.conf", "*.html"], "evatool.bin": ["*"]},
    # packages=find_packages(exclude=["test", "test.*"]),
    zip_safe=False,
)
